summaryrefslogtreecommitdiff
path: root/svx/source/sdr/primitive2d/sdrattributecreator.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2016-09-20 16:41:39 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2016-10-05 06:51:20 +0000
commit954f752cf10fc6a8777af2a6a93e496688464687 (patch)
tree0fc776cdcb6ad9b1d2b9673ac044bb5b4f496972 /svx/source/sdr/primitive2d/sdrattributecreator.cxx
parentc1e18e05a53c1d55afe36a887ca25f74f3f1d32d (diff)
convert MapUnit to scoped enum
I left a prefix on the names "Map" so that I would not have to re-arrange each name too much, since I can't start identifiers with digits like "100thMM" And remove RSC_EXTRAMAPUNIT, which doesn't seem to be doing anything anymore. Change-Id: I5187824aa87e30caf5357b51b5384b5ab919d224 Reviewed-on: https://gerrit.libreoffice.org/29096 Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk> Tested-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'svx/source/sdr/primitive2d/sdrattributecreator.cxx')
-rw-r--r--svx/source/sdr/primitive2d/sdrattributecreator.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/svx/source/sdr/primitive2d/sdrattributecreator.cxx b/svx/source/sdr/primitive2d/sdrattributecreator.cxx
index bbfbbd87d8fa..e150b19469f5 100644
--- a/svx/source/sdr/primitive2d/sdrattributecreator.cxx
+++ b/svx/source/sdr/primitive2d/sdrattributecreator.cxx
@@ -642,7 +642,7 @@ namespace drawinglayer
if(GraphicType::Bitmap == aGraphic.GetType())
{
aGraphic.SetPrefSize(aGraphic.GetBitmapEx().GetSizePixel());
- aGraphic.SetPrefMapMode(MAP_PIXEL);
+ aGraphic.SetPrefMapMode(MapUnit::MapPixel);
}
}
@@ -659,11 +659,11 @@ namespace drawinglayer
if(aGraphic.GetPrefMapMode() != aDestinationMapUnit)
{
// #i100360# for MAP_PIXEL, LogicToLogic will not work properly,
// so fallback to Application::GetDefaultDevice()
Size aNewSize(0, 0);
- if(MAP_PIXEL == aGraphic.GetPrefMapMode().GetMapUnit())
+ if(MapUnit::MapPixel == aGraphic.GetPrefMapMode().GetMapUnit())
{
aNewSize = Application::GetDefaultDevice()->PixelToLogic(
aGraphic.GetPrefSize(),
@@ -659,11 +659,11 @@ namespace drawinglayer
if(aGraphic.GetPrefMapMode() != aDestinationMapUnit)
{
- // #i100360# for MAP_PIXEL, LogicToLogic will not work properly,
+ // #i100360# for MapUnit::MapPixel, LogicToLogic will not work properly,
// so fallback to Application::GetDefaultDevice()
Size aNewSize(0, 0);